@@ -3,6 +3,7 @@ package uk.ac.starlink.table.gui;
 import java.awt.Component;
 import java.util.Iterator;
 import java.util.logging.Logger;
+import javax.swing.JLabel;
 import javax.swing.JTable;
 import javax.swing.SwingConstants;
 import javax.swing.UIManager;
@@ -214,6 +215,21 @@ public class StarJTable extends JTable {
                                  : JTable.AUTO_RESIZE_OFF );
     }
 
+    /**
+     * Sets up numeric cell renderers for the columns of a JTable.
+     *
+     * @param  jtable  table to configure; does not have to be a StarJTable
+     */
+    public static void configureDefaultRenderers( JTable jtable ) {
+        for ( Class<?> clazz : new Class<?>[] {
+                  Byte.class, Short.class, Integer.class, Long.class,
+                  Float.class, Double.class,
+              } ) {
+            jtable.setDefaultRenderer( clazz,
+                                       new NumericCellRenderer( clazz ) );
+        }
+    }
+
     /**
      * Sets the width of one column to match the width of its contents.
      * A heuristic * method is used; the widths of the headers and of 
@@ -236,6 +252,20 @@ public class StarJTable extends JTable {
         table.getColumnModel().getColumn( icol ).setPreferredWidth( width );
     }
 
+    /**
+     * Utility method that tries to arrange for the column headers to be
+     * left-aligned rather than, as seems to be the default, center-aligned.
+     *
+     * @param  jtable  table to affect
+     */
+    public static void alignHeadersLeft( JTable jtable ) {
+        TableCellRenderer hdrRend =
+            jtable.getTableHeader().getDefaultRenderer();
+        if ( hdrRend instanceof JLabel ) {
+            ((JLabel) hdrRend).setHorizontalAlignment( SwingConstants.LEFT );
+        }
+    }
+
     /**
      * Gets the width that it looks like a given column should have.
      *
